# Change Log

## 0.1.0 (2021-06-21)

The first official release of pddl.

Main features:
* Specify PDDL domains and problems programmatically.
* Parsing for PDDL domains and problems.

## 0.0.1 (2020-07-30)

* First commit on the package.

